﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Diagnostics;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Data;
using System.Windows.Input;
using System.Windows.Media;
using Abt.Controls.SciChart;
using Abt.Controls.SciChart.Common.Extensions;
using Abt.Controls.SciChart.Model.DataSeries;
using Abt.Controls.SciChart.Visuals;
using Abt.Controls.SciChart.Visuals.Annotations;
using Abt.Controls.SciChart.Visuals.Axes;
using TestControlProject.Annotations;

namespace TestControlProject
{
    public class MainWindowViewModel:INotifyPropertyChanged
    {
        private AnnotationCollection _annotationCollection = new AnnotationCollection();
        private ICommand _mouseDoubleClickCommand;                                 
        private ObservableCollection<IChartSeriesViewModel> _graphicsCollection=new ObservableCollection<IChartSeriesViewModel>();                    
        private AxisBase _xAxis;
        private AxisCollection _yAxisCollection = new AxisCollection();

        public AxisBase XAxis
        {
            get { return _xAxis; }
            set
            {
                if (Equals(value, _xAxis)) return;
                _xAxis = value;
                OnPropertyChanged("XAxis");
            }
        }

        public AxisCollection YAxisCollection
        {
            get { return _yAxisCollection; }
            set
            {
                if (Equals(value, _yAxisCollection)) return;
                _yAxisCollection = value;
                OnPropertyChanged("YAxisCollection");
            }
        }

        public AnnotationCollection AnnotationCollection
        {
            get { return _annotationCollection; }
            set
            {
                if (Equals(value, _annotationCollection)) return;
                _annotationCollection = value;
                OnPropertyChanged("AnnotationCollection");
            }
        }

        public ObservableCollection<IChartSeriesViewModel> GraphicsCollection
        {
            get { return _graphicsCollection; }
            set
            {
                if (_graphicsCollection != value)
                {
                    _graphicsCollection = value;
                }
                OnPropertyChanged("GraphicsCollection");
            }
        }

        public MainWindowViewModel()
        {
            InitializerSettings();
        }

        private void InitializerSettings()
        {
            InitializeAxes();
            InitializeYAxisCollection();
            AddAnnotation();
        }

        private void InitializeAxes()
        {
            XAxis = new NumericAxis
            {
                //VisibleRange = new DoubleRange(),
                //AutoRange = AutoRange.Once,
                DrawLabels = true,
                DrawMajorBands = true,
                //DrawMajorGridLines = true,
                DrawMinorGridLines = false,
                AxisTitle = "X-axis"
            };
        }

        private void InitializeYAxisCollection()
        {
            var y = new NumericAxis
            {
                AxisTitle = "Y-axis",
                //AutoRange = AutoRange.Once,
                VisibleRange = new DoubleRange(),
                AxisAlignment = AxisAlignment.Right,
                AutoTicks = true,
                DrawLabels = true,
                DrawMajorBands = true,
                DrawMinorGridLines = false,
                Width = 50
            };
            YAxisCollection.Add(y);
        }

        private void AddAnnotation()
        {
            AnnotationCollection.Add(CreateHorizontalLine(10* 0.25));
        }

        private IAnnotation CreateHorizontalLine(double yValue)
        {
            return new HorizontalLineAnnotation()
            {
                Y1 = yValue,
                HorizontalAlignment = HorizontalAlignment.Stretch,
                StrokeDashArray = new DoubleCollection(new double[] {8, 8}),
                StrokeThickness = 1,
                Stroke = new SolidColorBrush(Colors.Gray),
                AllowDrop = false,
                IsSelected = false,
                IsEditable = false,
                IsEnabled = false,
                IsManipulationEnabled = false,
                IsTabStop = false,
                ShowLabel = true
            };
        }



        public event PropertyChangedEventHandler PropertyChanged;

        [NotifyPropertyChangedInvocator]
        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            var handler = PropertyChanged;
            if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
